@@ -2,7 +2,7 @@ package Benchmarks;
 use strict;
 use warnings;
 use Benchmark qw/ :hireswallclock /;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub import {
     my ($class, $code, $count, $style, $title) = @_;
@@ -12,9 +12,16 @@ sub import {
     return unless $code;
     return unless ref $code eq 'CODE';
 
-    my $ret  = $code->();
-    $count   = !defined($count) ? -1 : $count;
-    $style ||= 'auto';
+    my ($ret, $runtime_count, $runtime_style, $runtime_title)  = $code->();
+    $count = defined($runtime_count) ? $runtime_count
+           : defined($count)         ? $count
+           : -1;
+    $style = defined($runtime_style) ? $runtime_style
+           : defined($style)         ? $style
+           : 'auto';
+    $title = defined($runtime_title) ? $runtime_title
+           : defined($title)         ? $title
+           : undef;
 
     _run_benchmark($count, $ret, $style, $title);
 }
@@ -25,7 +32,7 @@ sub _run_benchmark {
     my $ref_ret = ref $ret;
 
     if ( !$ref_ret || $ref_ret eq 'CODE' ) {
-        Benchmark::timethis($count, $ret, $title || undef, $style);
+        Benchmark::timethis($count, $ret, $title, $style);
     }
     elsif ( $ref_ret eq 'HASH' ) {
         Benchmark::cmpthese($count, $ret, $style);
@@ -59,7 +66,7 @@ Benchmarks - The comparison benchmarker
 
 B<Benchmarks> is the L<Benchamark> wrapper for comparing routines easily.
 
-When this module was loaded, all you need to do is pass the CODE reference that returns hash reference.
+When this module was loaded, all you need to do is pass the CODE reference that returns the hash reference.
 
     use Benchmarks sub {
         +{
@@ -92,7 +99,7 @@ then the result like this.
 
 =head2 MORE FUNCTIONS
 
-C<Benchmarks> exports *ALL* functions from C<Benchmark>. You can use C<Benchmarks> module as same as Benchmark module.
+C<Benchmarks> exports B<*ALL*> functions from C<Benchmark>. You can use C<Benchmarks> module as same as C<Benchmark> module.
 
     use Benchmarks;
 
@@ -104,7 +111,7 @@ More information about functions: L<https://metacpan.org/pod/Benchmark#Standard-
 
 =head2 BENCHMARKS ARGS
 
-When you use C<Benchmarks>, you can throw few args like below.
+When you use C<Benchmarks>, you can throw several args like below.
 
     use Benchmarks sub {
         # benchmark hash or code.
@@ -127,14 +134,21 @@ example STYLE and TITLE:
         sub { $x * $x };
     }, 100, 'all', '2 times';
 
+You can pass(return) these args at runtime.
+
+    use Benchmarks sub {
+        my $x = 2;
+        sub { $x * $x }, 100, 'all', '2 times';
+    };
+
 
 =head2 BENCHMARK TEMPLATE
 
-This module includes the `penchmark` command. It's generator of the C<Benchmarks> template.
+This module includes the L<penchmarks> command. It's generator of the C<Benchmarks> template.
 
-    $ penchmarks FILE_PATH
+    $ penchmarks GENERATE_BENCHMARK_FILE_PATH
 
-Then you can edit the C<FILE_PATH> file.
+Then you can edit the C<GENERATE_BENCHMARK_FILE_PATH> file and run it.
 
 
 =head1 REPOSITORY
